@@ -7,6 +7,7 @@ from typing import Dict, Iterable, List, Optional, Set, Tuple, Type, Union
 
 from .const import (  # imported for back compat, remove once Home Assistant no longer uses
     ADDRESSABLE_STATE_CHANGE_LATENCY,
+    ATTR_MODEL_DESCRIPTION,
     CHANNEL_STATES,
     COLOR_MODE_CCT,
     COLOR_MODE_DIM,
@@ -52,7 +53,7 @@ from .pattern import (
     EFFECT_CUSTOM_CODE,
     EFFECT_ID_NAME,
     EFFECT_LIST,
-    EFFECT_LIST_DIMMABLE,
+    EFFECT_LIST_AUTO_ON,
     ORIGINAL_ADDRESSABLE_EFFECT_ID_NAME,
     ORIGINAL_ADDRESSABLE_EFFECT_NAME_ID,
     PresetPattern,
@@ -85,6 +86,7 @@ from .protocol import (
     ProtocolLEDENETCCT,
     ProtocolLEDENETOriginal,
 )
+from .scanner import FluxLEDDiscovery
 from .timer import BuiltInTimer
 from .utils import scaled_color_temp_to_white_levels, utils, white_levels_to_color_temp
 
@@ -166,6 +168,7 @@ class LEDENETDevice:
         self.available: Optional[bool] = None
         self._model_num: Optional[int] = None
         self._model_data: Optional[LEDENETModel] = None
+        self._discovery: Optional[FluxLEDDiscovery] = None
         self._protocol: Optional[PROTOCOL_TYPES] = None
         self._mode: Optional[str] = None
         self._transition_complete_time: float = 0
@@ -183,6 +186,16 @@ class LEDENETDevice:
         assert self._model_data is not None
         return self._model_data
 
+    @property
+    def discovery(self) -> Optional[FluxLEDDiscovery]:
+        """Return the discovery data."""
+        return self._discovery
+
+    @discovery.setter
+    def discovery(self, value: FluxLEDDiscovery) -> None:
+        """Set the discovery data."""
+        self._discovery = value
+
     @property
     def speed_adjust_off(self) -> int:
         """Return true if the speed of an effect can be adjusted while off."""
@@ -196,6 +209,8 @@ class LEDENETDevice:
     @property
     def model(self) -> str:
         """Return the human readable model description."""
+        if self._discovery and self._discovery[ATTR_MODEL_DESCRIPTION]:
+            return f"{self._discovery[ATTR_MODEL_DESCRIPTION]} (0x{self.model_num:02X})"
         return f"{self.model_data.description} (0x{self.model_num:02X})"
 
     @property
@@ -368,7 +383,7 @@ class LEDENETDevice:
         elif protocol in CHRISTMAS_EFFECTS_PROTOCOLS:
             effects = CHRISTMAS_ADDRESSABLE_EFFECT_ID_NAME.values()
         elif COLOR_MODES_RGB.intersection(self.color_modes):
-            effects = EFFECT_LIST_DIMMABLE if self.dimmable_effects else EFFECT_LIST
+            effects = EFFECT_LIST if self.requires_turn_on else EFFECT_LIST_AUTO_ON
         if self.microphone:
             return [*effects, EFFECT_RANDOM, EFFECT_MUSIC]
         return [*effects, EFFECT_RANDOM]
@@ -935,7 +950,7 @@ class LEDENETDevice:
         else:
             PresetPattern.valtostr(pattern)
             if not PresetPattern.valid(pattern):
-                raise ValueError("Pattern must be between 0x25 and 0x3a")
+                raise ValueError("Pattern must be between 0x24 and 0x3a")
         if not (1 <= brightness <= 100):
             raise ValueError("Brightness must be between 1 and 100")
         self._last_effect_brightness = brightness
